@@ -1,4 +1,4 @@
-for i in de eo nl pt_BR fr; do
+for i in de eo nl pt_BR fr pl; do
 	msgfmt -v $i -o `basename $i .po`.mo
 done
 mv *.mo ..
